/*******************************************************************************
 * Copyright 2013 André Rouél
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package net.sf.uadetector.json.internal.data.deserializer;

import java.util.List;

/**
 * An instance of this class represents the result of an deserialization.
 */
public final class Deserialization<T> {

	private final T data;

	private final List<String> warnings;

	public Deserialization(final T data, final List<String> warnings) {
		this.data = data;
		this.warnings = warnings;
	}

	public T getData() {
		return data;
	}

	/**
	 * Returns a list of warnings that caused during deserialization.
	 * 
	 * @return list of warnings
	 */
	public List<String> getWarnings() {
		return warnings;
	}

}
